==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/change/vo/ChangesubpackageVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordsubpackageVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算变更
 * 
 * @author generator
 * 
 */
public class ChangesubpackageVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long originalId; // 原始单据id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long subcontractUnit; // 分包单位
    private java.lang.String subcontractUnitName; // 分包单位名称
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    
    private List<ChangesubpackagedetailVO> subpackagedetailEntities= new ArrayList<>(); // 分包施工图预算变更子表
    private List<RecordsubpackageVO>  recordsubpackageList = new ArrayList<>(); //变更记录历史信息

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    @ReferDeserialTransfer
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    @ReferDeserialTransfer
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
     /**
      * 分包施工图预算变更子表
      */
    public List<ChangesubpackagedetailVO> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }

    /**
     * 分包施工图预算变更子表
     */
    public void setSubpackagedetailEntities(List<ChangesubpackagedetailVO> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }

    public List<RecordsubpackageVO> getRecordsubpackageList() {
        return recordsubpackageList;
    }

    public void setRecordsubpackageList(List<RecordsubpackageVO> recordsubpackageList) {
        this.recordsubpackageList = recordsubpackageList;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220407.084509-69-sources.jar: com/ejianc/business/change/vo/ChangesubpackageVO.java <==
package com.ejianc.business.change.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordsubpackageVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算变更
 * 
 * @author generator
 * 
 */
public class ChangesubpackageVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long originalId; // 原始单据id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long subcontractUnit; // 分包单位
    private java.lang.String subcontractUnitName; // 分包单位名称
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间

    private java.math.BigDecimal excludingTaxUnitPriceTotal; // 除税单价合计
    private java.math.BigDecimal includingTaxUnitPriceTotal; // 含税单价合计
    
    private List<ChangesubpackagedetailVO> subpackagedetailEntities= new ArrayList<>(); // 分包施工图预算变更子表
    private List<RecordsubpackageVO>  recordsubpackageList = new ArrayList<>(); //变更记录历史信息

    public BigDecimal getExcludingTaxUnitPriceTotal() {
        return excludingTaxUnitPriceTotal;
    }

    public void setExcludingTaxUnitPriceTotal(BigDecimal excludingTaxUnitPriceTotal) {
        this.excludingTaxUnitPriceTotal = excludingTaxUnitPriceTotal;
    }

    public BigDecimal getIncludingTaxUnitPriceTotal() {
        return includingTaxUnitPriceTotal;
    }

    public void setIncludingTaxUnitPriceTotal(BigDecimal includingTaxUnitPriceTotal) {
        this.includingTaxUnitPriceTotal = includingTaxUnitPriceTotal;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    @ReferDeserialTransfer
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    @ReferDeserialTransfer
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
     /**
      * 分包施工图预算变更子表
      */
    public List<ChangesubpackagedetailVO> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }

    /**
     * 分包施工图预算变更子表
     */
    public void setSubpackagedetailEntities(List<ChangesubpackagedetailVO> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }

    public List<RecordsubpackageVO> getRecordsubpackageList() {
        return recordsubpackageList;
    }

    public void setRecordsubpackageList(List<RecordsubpackageVO> recordsubpackageList) {
        this.recordsubpackageList = recordsubpackageList;
    }
}
